Crate enum_tree
enum_
tree
0.1.0
All Items
Crate Items
Traits
Derive Macros
Crate
enum_
tree
Traits

Deep
Count
Convenience companion trait that exposes the length of
DeepVariants::DEEP_VARIANTS
without dereferencing the slice.
Deep
Variants
Types that expose every reachable value as a compile-time constant slice.
Derive Macros

Deep
Variants
Create a const array with all possible values of an enum. Target must be an
enum
, and each variant of the target must be of
nested unit type
. A variant is of nested unit type if it is either:
Enum
From
Derive From implementations for an enum from variants.
Into
Ancestors
Derive
From<Self>
for every enum mentioned in an
#[ancestors(Parent::Variant)]
attribute.